@@ -37,22 +37,17 @@ class DDLParser(Parser):
         r'[0-9]+\D'
         t.type = "NUM_VALUE_SDP"
         t.value = t.value.replace(')', '')
-        print(t.value)
-        print(t.type)
         return t
 
     def t_ID(self, t):
         r'[a-zA-Z_][a-zA-Z_0-9:]*'
-        print(t.value)
         t.type = self.reserved.get(t.value.upper(), 'ID')  # Check for reserved word
-        print(t.type)
         return t
 
     def t_newline(self, t):
         r'\n+'
         self.lexer.lineno += len(t.value)
         t.type = "NEWLINE"
-        print(t.type)
         if self.lexer.paren_count == 0:
             return t
 
@@ -60,7 +55,6 @@ class DDLParser(Parser):
         raise SyntaxError("Unknown symbol %r" % (t.value[0],))
 
     def p_error(self, p):
-        print('errrrror')
         pass
 
     def p_expression_table_name(self, p):
@@ -91,9 +85,7 @@ class DDLParser(Parser):
                   | ID ID NUM_VALUE_SDP
                   | ID NUM_VALUE_SDP
         """
-        print('p_expression_column_type')
         size = None
-        print([x for x in p])
         type_str = p[2]
         if len(p) == 4:
             match = re.match(r'[0-9]+', p[3])
@@ -111,13 +103,10 @@ class DDLParser(Parser):
                 | column PRIMARY KEY
                 | column DEFAULT ID
         """
-        print('p_expression_type')
         pk = False
         nullable = False
         default = None
-        print([x for x in p])
         p[0] = p[1]
-        print([x for x in p])
         if 'KEY' in p and 'PRIMARY' in p:
             pk = True
         if 'NULL' in p and 'NOT' not in p:
@@ -184,9 +173,7 @@ class DDLParser(Parser):
     def run(self, *, dump=None, dump_path="schemas", lower_case=False):
         """ run lex and yacc on prepared data from files """
         result = super().run()
-        print(result)
         table_data = self.result_format(result)
-        print(table_data)
         if dump:
             self.dump_schema(table_data['table_name'], dump_path)
         return table_data
@@ -195,22 +182,3 @@ def parse_from_file(file_path: str, **kwargs):
     """ get useful data from ddl """
     with open(file_path, 'r') as df:
         return DDLParser(df.read()).run(**kwargs)
-
-ddl = """
-
-CREATE TABLE "countries" (
-  "id" int PRIMARY KEY,
-  "code" varchar(4) NOT NULL,
-  "name" varchar NOT NULL
-);
-
-CREATE TABLE "path_owners" (
-  "user_id" int,
-  "path_id" int,
-  "type" int DEFAULT 1a
-);
-
-
-"""
-
-print(DDLParser(ddl).run())
\ No newline at end of file
